=============
API Reference
=============

In-depth documentation for Horizon framework and its APIs.

.. toctree::
   :maxdepth: 1

   horizon
   workflows
   tables
   tabs
   forms
   middleware
   context_processors
   decorators
   exceptions
   test
   local_conf

Auth API Reference
==================

.. toctree::
   :maxdepth: 2
   :glob:

   openstack_auth/*
